@@ -77,7 +77,7 @@ class Witter():
         self.busyCounter = 0
         self.search_terms = ""
         self.refreshtask = None
-        self.dmresfresh = None
+        self.dmrefresh = None
         self.mentionrefresh = None
         self.publicrefresh = None
         self.searchrefresh = None
